@@ -1,3 +1,7 @@
+#![warn(missing_docs)]
+//! Tells when responses can be reused from a cache, taking into account [HTTP RFC 7234](http://httpwg.org/specs/rfc7234.html) rules for user agents and shared caches.
+//! It's aware of many tricky details such as the `Vary` header, proxy revalidation, and authenticated responses.
+
 use chrono::prelude::*;
 use http::HeaderMap;
 use http::HeaderValue;
@@ -11,17 +15,6 @@ use std::collections::HashMap;
 use std::time::Duration;
 use std::time::SystemTime;
 
-trait GetHeaderStr {
-    fn get_str(&self, k: &str) -> Option<&str>;
-}
-
-impl GetHeaderStr for HeaderMap {
-    #[inline]
-    fn get_str(&self, k: &str) -> Option<&str> {
-        self.get(k).and_then(|v| v.to_str().ok())
-    }
-}
-
 // rfc7231 6.1
 const STATUS_CODE_CACHEABLE_BY_DEFAULT: &[u16] =
     &[200, 203, 204, 206, 300, 301, 404, 405, 410, 414, 501];
@@ -58,7 +51,8 @@ fn parse_cache_control<'a>(headers: impl IntoIterator<Item = &'a HeaderValue>) -
     let mut is_valid = true;
 
     for h in headers.into_iter().filter_map(|v| v.to_str().ok()) {
-        for part in h.split(',') { // TODO: lame parsing
+        for part in h.split(',') {
+            // TODO: lame parsing
             if part.trim().is_empty() {
                 continue;
             }
@@ -75,10 +69,10 @@ fn parse_cache_control<'a>(headers: impl IntoIterator<Item = &'a HeaderValue>) -
                     if e.get().as_deref() != v {
                         is_valid = false;
                     }
-                },
+                }
                 Entry::Vacant(e) => {
                     e.insert(v.map(|v| v.trim_matches('"')).map(From::from)); // TODO: bad unquoting
-                },
+                }
             }
         }
     }
@@ -88,18 +82,6 @@ fn parse_cache_control<'a>(headers: impl IntoIterator<Item = &'a HeaderValue>) -
     cc
 }
 
-fn join<'a>(parts: impl Iterator<Item = &'a str>) -> String {
-    let mut out = String::new();
-    for part in parts {
-        out.reserve(2 + part.len());
-        if !out.is_empty() {
-            out.push_str(", ");
-        }
-        out.push_str(part);
-    }
-    out
-}
-
 fn format_cache_control(cc: &CacheControl) -> String {
     let mut out = String::new();
     for (k, v) in cc {
@@ -109,22 +91,54 @@ fn format_cache_control(cc: &CacheControl) -> String {
         out.push_str(k);
         if let Some(v) = v {
             out.push('=');
-            let needs_quote = v.is_empty() || v.as_bytes().iter().any(|b| !b.is_ascii_alphanumeric());
-            if needs_quote { out.push('"'); }
+            let needs_quote =
+                v.is_empty() || v.as_bytes().iter().any(|b| !b.is_ascii_alphanumeric());
+            if needs_quote {
+                out.push('"');
+            }
             out.push_str(v);
-            if needs_quote { out.push('"'); }
+            if needs_quote {
+                out.push('"');
+            }
         }
     }
     out
 }
 
+/// Holds configuration options which control the behavior of the cache and
+/// are independent of any specific request or response.
 #[derive(Debug, Copy, Clone)]
+#[cfg_attr(feature = "with_serde", derive(serde_derive::Serialize, serde_derive::Deserialize))]
 pub struct CachePolicyOptions {
+    /// If `shared` is `true` (default), then the response is evaluated from a
+    /// perspective of a shared cache (i.e. `private` is not cacheable and
+    /// `s-maxage` is respected). If `shared` is `false`, then the response is
+    /// evaluated from a perspective of a single-user cache (i.e. `private` is
+    /// cacheable and `s-maxage` is ignored). `shared: true` is recommended
+    /// for HTTP clients.
     pub shared: bool,
+    /// `cache_heuristic` is a fraction of response's age that is used as a
+    /// fallback cache duration. The default is 0.1 (10%), e.g. if a file
+    /// hasn't been modified for 100 days, it'll be cached for 100*0.1 = 10
+    /// days.
     pub cache_heuristic: f32,
+    /// `immutable_min_time_to_live` is a duration to assume as the
+    /// default time to cache responses with `Cache-Control: immutable`. Note
+    /// that per RFC these can become stale, so `max-age` still overrides the
+    /// default.
     pub immutable_min_time_to_live: Duration,
+    /// If `ignore_cargo_cult` is `true`, common anti-cache directives will be
+    /// completely ignored if the non-standard `pre-check` and `post-check`
+    /// directives are present. These two useless directives are most commonly
+    /// found in bad StackOverflow answers and PHP's "session limiter"
+    /// defaults.
     pub ignore_cargo_cult: bool,
+    /// If `trust_server_date` is `false`, then server's `Date` header won't
+    /// be used as the base for `max-age`. This is against the RFC, but it's
+    /// useful if you want to cache responses with very short `max-age`, but
+    /// your local clock is not exactly in sync with the server's.
     pub trust_server_date: bool,
+    /// When the response has been received. `SystemTime::now`.
     pub response_time: SystemTime,
 }
 
@@ -141,12 +155,22 @@ impl Default for CachePolicyOptions {
     }
 }
 
+/// Identifies when responses can be reused from a cache, taking into account
+/// HTTP RFC 7234 rules for user agents and shared caches. It's aware of many
+/// tricky details such as the Vary header, proxy revalidation, and
+/// authenticated responses.
 #[derive(Debug)]
+#[cfg_attr(feature = "with_serde", derive(serde_derive::Serialize, serde_derive::Deserialize))]
 pub struct CachePolicy {
+    #[cfg_attr(feature = "with_serde", serde(with = "http_serde::header_map"))]
     req: HeaderMap,
+    #[cfg_attr(feature = "with_serde", serde(with = "http_serde::header_map"))]
     res: HeaderMap,
+    #[cfg_attr(feature = "with_serde", serde(with = "http_serde::uri"))]
     uri: Uri,
+    #[cfg_attr(feature = "with_serde", serde(with = "http_serde::status_code"))]
     status: StatusCode,
+    #[cfg_attr(feature = "with_serde", serde(with = "http_serde::method"))]
     method: Method,
     opts: CachePolicyOptions,
     res_cc: CacheControl,
@@ -154,16 +178,30 @@ pub struct CachePolicy {
 }
 
 impl CachePolicy {
-    pub fn new<ReqBody, ResBody>(
-        req: &Request<ReqBody>,
-        res: &Response<ResBody>,
+    /// Cacheability of an HTTP response depends on how it was requested, so
+    /// both request and response are required to create the policy.
+    #[inline]
+    pub fn new<Req: RequestLike, Res: ResponseLike>(
+        req: &Req,
+        res: &Res,
         opts: CachePolicyOptions,
     ) -> Self {
         let uri = req.uri().clone();
         let status = res.status();
         let method = req.method().clone();
-        let mut res = res.headers().clone();
+        let res = res.headers().clone();
         let req = req.headers().clone();
+        Self::from_details(uri, method, status, req, res, opts)
+    }
+
+    fn from_details(
+        uri: Uri,
+        method: Method,
+        status: StatusCode,
+        req: HeaderMap,
+        mut res: HeaderMap,
+        opts: CachePolicyOptions,
+    ) -> Self {
         let mut res_cc = parse_cache_control(res.get_all("cache-control"));
         let req_cc = parse_cache_control(req.get_all("cache-control"));
 
@@ -208,7 +246,9 @@ impl CachePolicy {
         }
     }
 
-    pub fn storable(&self) -> bool {
+    /// Returns `true` if the response can be stored in a cache. If it's
+    /// `false` then you MUST NOT store either the request or the response.
+    pub fn is_storable(&self) -> bool {
         // The "no-store" request directive indicates that a cache MUST NOT store any part of either this request or any response to it.
         !self.req_cc.contains_key("no-store") &&
             // A cache MUST NOT store a response to any request, unless:
@@ -232,9 +272,9 @@ impl CachePolicy {
                 // contains a max-age response directive, or
                 // contains a s-maxage response directive and the cache is shared, or
                 // contains a public response directive.
-                self.res_cc.contains_key("public") ||
                 self.res_cc.contains_key("max-age") ||
-                self.res_cc.contains_key("s-maxage") ||
+                (self.opts.shared && self.res_cc.contains_key("s-maxage")) ||
+                self.res_cc.contains_key("public") ||
                 // has a status code that is defined as cacheable by default
                 STATUS_CODE_CACHEABLE_BY_DEFAULT.contains(&self.status.as_u16()))
     }
@@ -246,18 +286,29 @@ impl CachePolicy {
             || self.res.contains_key("expires")
     }
 
-    pub fn satisfies_without_revalidation<Body>(
+    /// Returns whether the cached response is still fresh in the context of
+    /// the new request.
+    ///
+    /// If it returns `true`, then the given request matches the original
+    /// response this cache policy has been created with, and the response can
+    /// be reused without contacting the server.
+    ///
+    /// If it returns `false`, then the response may not be matching at all
+    /// (e.g. it's for a different URL or method), or may require to be
+    /// refreshed first. Either way, the new request's headers will have been
+    /// updated for sending it to the origin server.
+    pub fn satisfies_without_revalidation<Req: RequestLike>(
         &self,
-        req: &Request<Body>,
+        req: &Req,
         now: SystemTime,
     ) -> bool {
+        let req_headers = req.headers();
         // When presented with a request, a cache MUST NOT reuse a stored response, unless:
         // the presented request does not contain the no-cache pragma (Section 5.4), nor the no-cache cache directive,
         // unless the stored response is successfully validated (Section 4.3), and
-        let req_cc = parse_cache_control(req.headers().get_all("cache-control"));
+        let req_cc = parse_cache_control(req_headers.get_all("cache-control"));
         if req_cc.contains_key("no-cache")
-            || req
-                .headers()
+            || req_headers
                 .get_str("pragma")
                 .map_or(false, |v| v.contains("no-cache"))
         {
@@ -286,22 +337,27 @@ impl CachePolicy {
 
         // the stored response is either:
         // fresh, or allowed to be served stale
-        if let Some(max_stale) = req_cc.get("max-stale") {
-            if !self.res_cc.contains_key("must-revalidate") && self.stale(now) {
-                let max_stale = max_stale.as_ref().and_then(|s| s.parse().ok());
-                let allows_stale = max_stale.map_or(true, |val| {
+        if self.is_stale(now) {
+            // If no value is assigned to max-stale, then the client is willing to accept a stale response of any age.
+            let max_stale = req_cc.get("max-stale");
+            let has_max_stale = max_stale.is_some();
+            let max_stale = max_stale
+                .and_then(|m| m.as_ref())
+                .and_then(|s| s.parse().ok());
+            let allows_stale = !self.res_cc.contains_key("must-revalidate")
+                && has_max_stale
+                && max_stale.map_or(true, |val| {
                     Duration::from_secs(val) > self.age(now) - self.max_age()
                 });
-                if !allows_stale {
-                    return false;
-                }
+            if !allows_stale {
+                return false;
             }
         }
 
         self.request_matches(req, false)
     }
 
-    fn request_matches<Body>(&self, req: &Request<Body>, allow_head_method: bool) -> bool {
+    fn request_matches<Req: RequestLike>(&self, req: &Req, allow_head_method: bool) -> bool {
         // The presented effective request URI and that of the stored response match, and
         &self.uri == req.uri() &&
             self.req.get("host") == req.headers().get("host") &&
@@ -320,7 +376,7 @@ impl CachePolicy {
             || self.res_cc.contains_key("s-maxage")
     }
 
-    fn vary_matches<Body>(&self, req: &Request<Body>) -> bool {
+    fn vary_matches<Req: RequestLike>(&self, req: &Req) -> bool {
         for name in get_all_comma(self.res.get_all("vary")) {
             // A Vary header field-value of "*" always fails to match
             if name == "*" {
@@ -337,7 +393,9 @@ impl CachePolicy {
     fn copy_without_hop_by_hop_headers(in_headers: &HeaderMap) -> HeaderMap {
         let mut headers = HeaderMap::with_capacity(in_headers.len());
 
-        for (h, v) in in_headers.iter().filter(|(h, _)| !HOP_BY_HOP_HEADERS.contains(&h.as_str()))
+        for (h, v) in in_headers
+            .iter()
+            .filter(|(h, _)| !HOP_BY_HOP_HEADERS.contains(&h.as_str()))
         {
             headers.insert(h.to_owned(), v.to_owned());
         }
@@ -349,7 +407,7 @@ impl CachePolicy {
 
         let new_warnings = join(
             get_all_comma(in_headers.get_all("warning")).filter(|warning| {
-                warning.trim_start().starts_with('1') // FIXME: match 100-199, not 1 or 1000
+                !warning.trim_start().starts_with('1') // FIXME: match 100-199, not 1 or 1000
             }),
         );
         if new_warnings.is_empty() {
@@ -360,6 +418,10 @@ impl CachePolicy {
         headers
     }
 
+    /// Updates and filters the response headers for a cached response before
+    /// returning it to a client. This function is necessary, because proxies
+    /// MUST always remove hop-by-hop headers (such as TE and Connection) and
+    /// update response's Age to avoid doubling cache time.
     pub fn response_headers(&self, now: SystemTime) -> HeaderMap {
         let mut headers = Self::copy_without_hop_by_hop_headers(&self.res);
         let age = self.age(now);
@@ -420,7 +482,7 @@ impl CachePolicy {
     }
 
     /// Value of the Age header, in seconds, updated for the current time.
-    fn age(&self, now: SystemTime) -> Duration {
+    pub fn age(&self, now: SystemTime) -> Duration {
         let mut age = self.age_header();
         if let Ok(since_date) = self.opts.response_time.duration_since(self.date()) {
             age = age.max(since_date);
@@ -445,7 +507,7 @@ impl CachePolicy {
     ///
     /// For an up-to-date value, see `time_to_live()`.
     pub fn max_age(&self) -> Duration {
-        if !self.storable() || self.res_cc.contains_key("no-cache") {
+        if !self.is_storable() || self.res_cc.contains_key("no-cache") {
             return Duration::from_secs(0);
         }
 
@@ -500,7 +562,8 @@ impl CachePolicy {
 
         if let Some(last_modified) = self.res.get_str("last-modified") {
             if let Ok(last_modified) = DateTime::parse_from_rfc2822(last_modified) {
-                let last_modified = SystemTime::UNIX_EPOCH + Duration::from_secs(last_modified.timestamp().max(0) as _);
+                let last_modified = SystemTime::UNIX_EPOCH
+                    + Duration::from_secs(last_modified.timestamp().max(0) as _);
                 if let Ok(diff) = server_date.duration_since(last_modified) {
                     let secs_left = diff.as_secs() as f64 * self.opts.cache_heuristic as f64;
                     return default_min_ttl.max(Duration::from_secs(secs_left as _));
@@ -511,11 +574,21 @@ impl CachePolicy {
         default_min_ttl
     }
 
+    /// Returns approximate time in _milliseconds_ until the response becomes
+    /// stale (i.e. not fresh).
+    ///
+    /// After that time (when `time_to_live() <= 0`) the response might not be
+    /// usable without revalidation. However, there are exceptions, e.g. a
+    /// client can explicitly allow stale responses, so always check with
+    /// `is_cached_response_fresh()`.
     pub fn time_to_live(&self, now: SystemTime) -> Duration {
-        self.max_age().checked_sub(self.age(now)).unwrap_or_default()
+        self.max_age()
+            .checked_sub(self.age(now))
+            .unwrap_or_default()
     }
 
-    pub fn stale(&self, now: SystemTime) -> bool {
+    /// Stale responses shouldn't be used without contacting the server (revalidation)
+    pub fn is_stale(&self, now: SystemTime) -> bool {
         self.max_age() <= self.age(now)
     }
 
@@ -525,13 +598,13 @@ impl CachePolicy {
     /// Hop by hop headers are always stripped.
     /// Revalidation headers may be added or removed, depending on request.
     ///
-    pub fn revalidation_headers<Body>(&self, incoming_req: &Request<Body>) -> HeaderMap {
+    pub fn revalidation_headers<Req: RequestLike>(&self, incoming_req: &Req) -> HeaderMap {
         let mut headers = Self::copy_without_hop_by_hop_headers(incoming_req.headers());
 
         // This implementation does not understand range requests
         headers.remove("if-range");
 
-        if !self.request_matches(incoming_req, true) || !self.storable() {
+        if !self.request_matches(incoming_req, true) || !self.is_storable() {
             // revalidation allowed via HEAD
             // not for the same resource, or wasn't allowed to be cached anyway
             headers.remove("if-none-match");
@@ -584,8 +657,8 @@ impl CachePolicy {
     /// whether the response body has been modified, and old cached body can't be used.
     pub fn revalidated_policy<ReqB, ResB>(
         &self,
-        request: Request<ReqB>,
-        mut response: Response<ResB>,
+        request: &Request<ReqB>,
+        response: &mut Response<ResB>,
     ) -> RevalidatedPolicy {
         let old_etag = self.res.get_str("etag").map(str::trim);
         let old_last_modified = response.headers().get_str("last-modified").map(str::trim);
@@ -636,7 +709,7 @@ impl CachePolicy {
         }
 
         RevalidatedPolicy {
-            policy: CachePolicy::new(&request, &response, self.opts),
+            policy: CachePolicy::new(request, &*response, self.opts),
             // Client receiving 304 without body, even if it's invalid/mismatched has no option
             // but to reuse a cached body. We don't have a good way to tell clients to do
             // error recovery in such case.
@@ -646,9 +719,15 @@ impl CachePolicy {
     }
 }
 
+/// New policy and flags
 pub struct RevalidatedPolicy {
+    /// New policy with new headers
     pub policy: CachePolicy,
+    /// Boolean indicating whether the response body has changed.
+    /// If `false`, then a valid 304 Not Modified response has been received, and you can reuse the old cached response body.
+    /// If `true`, you should use new response's body (if present), or make another request to the origin server without any conditional headers (i.e. don't use `revalidation_headers()` this time) to get the new resource.
     pub modified: bool,
+    /// This was a request for something else and can't be used?
     pub matches: bool,
 }
 
@@ -659,3 +738,65 @@ fn get_all_comma<'a>(
         .filter_map(|v| v.to_str().ok())
         .flat_map(|s| s.split(',').map(str::trim))
 }
+
+trait GetHeaderStr {
+    fn get_str(&self, k: &str) -> Option<&str>;
+}
+
+impl GetHeaderStr for HeaderMap {
+    #[inline]
+    fn get_str(&self, k: &str) -> Option<&str> {
+        self.get(k).and_then(|v| v.to_str().ok())
+    }
+}
+
+fn join<'a>(parts: impl Iterator<Item = &'a str>) -> String {
+    let mut out = String::new();
+    for part in parts {
+        out.reserve(2 + part.len());
+        if !out.is_empty() {
+            out.push_str(", ");
+        }
+        out.push_str(part);
+    }
+    out
+}
+
+/// Allows using either Request or request::Parts, or your own newtype.
+pub trait RequestLike {
+    /// Same as `req.uri()`
+    fn uri(&self) -> &Uri;
+    /// Same as `req.method()`
+    fn method(&self) -> &Method;
+    /// Same as `req.headers()`
+    fn headers(&self) -> &HeaderMap;
+}
+
+/// Allows using either Response or response::Parts, or your own newtype.
+pub trait ResponseLike {
+    /// Same as `res.status()`
+    fn status(&self) -> StatusCode;
+    /// Same as `res.headers()`
+    fn headers(&self) -> &HeaderMap;
+}
+
+impl<Body> RequestLike for Request<Body> {
+    fn uri(&self) -> &Uri {
+        self.uri()
+    }
+    fn method(&self) -> &Method {
+        self.method()
+    }
+    fn headers(&self) -> &HeaderMap {
+        self.headers()
+    }
+}
+
+impl<Body> ResponseLike for Response<Body> {
+    fn status(&self) -> StatusCode {
+        self.status()
+    }
+    fn headers(&self) -> &HeaderMap {
+        self.headers()
+    }
+}
